# Setup Instructions  {#setup-instructions}

\tableofcontents

## Obtain the Code

The preferred way to obtain waLBerla is directly from its Git repository.
There are multiple ways to do this,
depending on how you plan to interact with the framework.

 - If you plan to build and work directly on waLBerla and the benchmarks and applications shipped with it,
   refer to [stand-alone clone](#git-standalone).
 - If you wish to include waLBerla into another CMake project,
   you can either use a [git submodule](#git-submodule) (which might be more stable)
   or [FetchContent](#git-fetchcontent) (which is often more convenient and easier to reproduce).

Once the basic project setup is complete, move on to the section on [build system configuration](#build-system-config).

### Standalone  {#git-standalone}

To work directly within the waLBerla source tree, simply clone the main [Git repository](https://i10git.cs.fau.de/walberla/walberla):

```bash
git clone https://i10git.cs.fau.de/walberla/walberla.git
```

If you mean to extend waLBerla's code base for your own purposes, or contribute to waLBerla's development,
you should create a fork off the main repository and clone the forked repo instead.

### As a Git Submodule  {#git-submodule}

To include waLBerla as a submodule, run the following commands inside your project folder:

```bash
git submodule add https://i10git.cs.fau.de/walberla/walberla.git
git submodule update --init
```

After waLBerla has been downloaded, `git commit ` the submodule.
You may then add waLBerla to your CMake project by adding the following to your root `CMakeLists.txt`:

```CMake
add_subdirectory( walberla )
```

### Using FetchContent  {#git-fetchcontent}

CMake allows us to download and include external projects into a build tree at configuration time using `FetchContent`.
This can be more convenient and easier to reproduce than Git submodules, or other ways of semi-manual installation.

To include waLBerla into your CMake project using `FetchContent`, add the following lines to your `CMakeLists.txt`:

```CMake
include(FetchContent)

FetchContent_Declare(
    walberla
    GIT_REPOSITORY https://i10git.cs.fau.de/walberla/walberla.git
    GIT_TAG <commit-hash / branch name / git tag>
)

FetchContent_MakeAvailable(walberla)
```

Using the `GIT_TAG` option you can specify the exact Git revision to include:
We recommend fixing this to a specific commit hash or tag to avoid surprising changes.
In this case, you will have to remember to regularily update this dependency.

## Configure the waLBerla Build System  {#build-system-config}

The waLBerla CMake system can be configured through a number of cache variables (see [below](#cmake-config-vars)).


## Reference: CMake Configuration Options  {#cmake-config-vars}
